@@ -174,10 +174,10 @@ class SmartOrchestrator:
         # Use custom system message from context if available, otherwise fallback to default
         system_prompt = context.get('system_message', "You are a helpful AI assistant. Provide clear, accurate, and concise responses to user queries.")
         
-        # Include memory context if available
+        # Include memory context if available - integrate naturally without mentioning it
         memory_context = context.get('memory_context', '')
         if memory_context.strip():
-            system_prompt += f"\n\nContext from previous conversations:\n{memory_context}"
+            system_prompt += f"\n\nBackground information that may be relevant (use naturally without explicitly mentioning context):\n{memory_context}\n\nImportant: Use this background information naturally in your response when relevant, but do not explicitly mention that you have context or previous conversation history unless directly asked about memory or conversation history."
         
         messages = [
             {"role": "system", "content": system_prompt},
