@@ -271,11 +271,18 @@ class TitansMemoryAdapter:
             # Combine and process memories
             all_contents = []
             
-            # Add session-specific inputs first
+            # Add session-specific inputs with similarity scoring
             for row in session_inputs:
                 content = row[0]
                 if content and content.strip():
-                    all_contents.append((content, "user_input", 1.0))  # Higher relevance for session data
+                    # Even session data should have semantic relevance
+                    similarity_score = SequenceMatcher(None, query.lower(), content.lower()).ratio()
+                    session_boost = 0.3  # Boost for being in same session
+                    combined_score = min(1.0, similarity_score + session_boost)
+                    
+                    # Only include session memories if they have some relevance
+                    if combined_score > 0.5:  # Higher threshold for inclusion
+                        all_contents.append((content, "user_input", combined_score))
             
             # Add session-specific outputs
             for row in session_outputs:
@@ -283,14 +290,20 @@ class TitansMemoryAdapter:
                 if content and content.strip() and len(content) < 500:  # Avoid very long responses
                     all_contents.append((content, "agent_response", 0.8))
             
-            # Add general inputs if needed (prioritize recent over semantic similarity)
+            # Add general inputs if needed with semantic similarity scoring
             for i, row in enumerate(general_inputs):
                 content = row[0]
                 if content and content.strip():
-                    # For conversation continuity, prioritize recent messages over semantic similarity
-                    # Recent messages get higher relevance scores (1.0 for most recent, decreasing)
-                    recency_score = max(0.3, 1.0 - (i * 0.1))  # Start at 1.0, decrease by 0.1 per position
-                    all_contents.append((content, "user_input", recency_score))
+                    # Calculate semantic similarity with current query
+                    similarity_score = SequenceMatcher(None, query.lower(), content.lower()).ratio()
+                    
+                    # Only include memories with reasonable similarity (> 0.3) or very recent ones
+                    recency_boost = max(0.1, 0.5 - (i * 0.05))  # Small recency boost
+                    combined_score = max(similarity_score, recency_boost)
+                    
+                    # Only add if there's meaningful similarity or it's very recent
+                    if combined_score > 0.4 or i < 2:  # High similarity OR very recent
+                        all_contents.append((content, "user_input", combined_score))
             
             # Convert to Titans memory format
             sqlite_memories = []
@@ -323,16 +336,16 @@ class TitansMemoryAdapter:
         if not relevant_memories:
             return ""
         
-        context_parts = ["Previous relevant context:"]
-        current_length = len(context_parts[0])
+        context_parts = []
+        current_length = 0
         
         for i, memory in enumerate(relevant_memories, 1):
             relevance = memory["relevance_score"]
             content = memory["content"]
             memory_type = memory["memory_type"]
             
-            # Format memory entry
-            entry = f"{i}. [{memory_type}] {content} (relevance: {relevance:.2f})"
+            # Format memory entry more naturally without metadata
+            entry = content
             
             # Rough token estimation (4 chars ≈ 1 token)
             entry_tokens = len(entry) // 4
